@@ -1,3 +1,5 @@
+import math
+
 from floraconcierge.client.types import Object
 
 
@@ -16,8 +18,10 @@ class Currency(Object):
 
             return int(value * multiplier) / multiplier
         else:
-            return int(self.rounding * int(value / self.rounding))
-
+            if self.rounding_direction == 'desc':
+                return int(self.rounding * math.ceil(value / self.rounding))
+            else:
+                return int(self.rounding * math.floor(value / self.rounding))
 
     def _format(self, value):
         return self.format % value
